summaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorBalbir Singh <balbir@linux.vnet.ibm.com>2008-12-17 15:21:57 +0000
committerBalbir Singh <balbir@linux.vnet.ibm.com>2008-12-17 15:21:57 +0000
commit7547c23c7c26779af88ccfd70fbbbc0376648208 (patch)
tree72dee46db1efa89c8c3489f51d9911977cacce37 /tests
parent5d16282a5f418bb7030ba33363bf570bec056a0b (diff)
downloadlibcg-7547c23c7c26779af88ccfd70fbbbc0376648208.tar.gz
libcg-7547c23c7c26779af88ccfd70fbbbc0376648208.tar.xz
libcg-7547c23c7c26779af88ccfd70fbbbc0376648208.zip
libcgroup Test: change error value to be checked
Chanhe the error values as per the change in APIs Signed-off-by: Sudhir Kumar <skumar@linux.vnet.ibm.com> git-svn-id: https://libcg.svn.sourceforge.net/svnroot/libcg/trunk@275 4f4bb910-9a46-0410-90c8-c897d4f1cd53
Diffstat (limited to 'tests')
-rw-r--r--tests/libcgrouptest01.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/libcgrouptest01.c b/tests/libcgrouptest01.c
index 5bd9dd5..46d2805 100644
--- a/tests/libcgrouptest01.c
+++ b/tests/libcgrouptest01.c
@@ -141,11 +141,11 @@ int main(int argc, char *argv[])
/*
* Test06: Check if cgroup_create_cgroup() handles a NULL cgroup
* Exp outcome: error ECGINVAL
*/
strncpy(extra, " Called with NULL cgroup argument\n", SIZE);
retval = cgroup_create_cgroup(nullcgroup, 1);
- if (retval)
+ if (retval == ECGROUPNOTINITIALIZED)
message(++i, PASS, "create_cgroup()", retval, extra);
else
message(++i, FAIL, "create_cgroup()", retval, extra);
@@ -341,7 +341,7 @@ int main(int argc, char *argv[])
retval = cgroup_modify_cgroup(nullcgroup);
/* No need to check if the values are changed */
- if (retval == ECGINVAL)
+ if (retval == ECGROUPNOTALLOWED)
message(++i, PASS, "modify_cgroup()", retval, extra);
else
message(++i, FAIL, "modify_cgroup()", retval, extra);
@@ -408,11 +408,11 @@ int main(int argc, char *argv[])
/*
* Test15: Check if cgroup_create_cgroup() handles a NULL cgroup
* Exp outcome: error ECGINVAL
*/
strncpy(extra, " Called with NULL cgroup argument\n", SIZE);
retval = cgroup_create_cgroup(nullcgroup, 1);
- if (retval)
+ if (retval == ECGROUPNOTALLOWED)
message(++i, PASS, "create_cgroup()", retval, extra);
else
message(++i, FAIL, "create_cgroup()", retval, extra);
@@ -141,11 +141,11 @@ int main(int argc, char *argv[])
/*
* Test06: Check if cgroup_create_cgroup() handles a NULL cgroup
- * Exp outcome: error ECGINVAL
+ * Exp outcome: error ECGROUPNOTALLOWED
*/
strncpy(extra, " Called with NULL cgroup argument\n", SIZE);
@@ -408,11 +408,11 @@ int main(int argc, char *argv[])
/*
* Test15: Check if cgroup_create_cgroup() handles a NULL cgroup
- * Exp outcome: error ECGINVAL
+ * Exp outcome: error ECGROUPNOTALLOWED
*/
strncpy(extra, " Called with NULL cgroup argument\n", SIZE);